==> zio-aws-networkfirewall_2.12-5.17.113.1-sources.jar: zio/aws/networkfirewall/model/AttachmentStatus.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters._
sealed trait AttachmentStatus {
  def unwrap
      : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus
}
object AttachmentStatus {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus
  ): zio.aws.networkfirewall.model.AttachmentStatus = value match {
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.CREATING =>
      val r = CREATING
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.DELETING =>
      val r = DELETING
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.SCALING =>
      val r = SCALING
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.READY =>
      val r = READY
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object CREATING extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.CREATING
  }
  case object DELETING extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.DELETING
  }
  case object SCALING extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.SCALING
  }
  case object READY extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.READY
  }
}

==> zio-aws-networkfirewall_2.12-6.20.162.2-sources.jar: zio/aws/networkfirewall/model/AttachmentStatus.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters._
sealed trait AttachmentStatus {
  def unwrap
      : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus
}
object AttachmentStatus {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus
  ): zio.aws.networkfirewall.model.AttachmentStatus = value match {
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.CREATING =>
      val r = CREATING
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.DELETING =>
      val r = DELETING
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.FAILED =>
      val r = FAILED
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.ERROR =>
      val r = ERROR
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.SCALING =>
      val r = SCALING
      r
    case software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.READY =>
      val r = READY
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object CREATING extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.CREATING
  }
  case object DELETING extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.DELETING
  }
  case object FAILED extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.FAILED
  }
  case object ERROR extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.ERROR
  }
  case object SCALING extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.SCALING
  }
  case object READY extends zio.aws.networkfirewall.model.AttachmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus =
      software.amazon.awssdk.services.networkfirewall.model.AttachmentStatus.READY
  }
}
